@@ -29,7 +29,12 @@ class Yosys(Edatool):
                     {
                         "name": "output_format",
                         "type": "String",
-                        "desc": "Output file format. Legal values are *json*, *edif*, *blif*",
+                        "desc": "Output file format. Legal values are *json*, *edif*, *blif*, *verilog*",
+                    },
+                    {
+                        "name": "output_name",
+                        "type": "String",
+                        "desc": "Output file name. [Optional]",
                     },
                     {
                         "name": "yosys_as_subtool",
@@ -83,7 +88,9 @@ class Yosys(Edatool):
         self.edam["files"] = unused_files
 
         output_format = self.tool_options.get("output_format", "blif")
-        default_target = f"{self.name}.{output_format}"
+        default_target = self.tool_options.get(
+            "output_name", f"{self.name}.{output_format}"
+        )
 
         self.edam["files"].append(
             {
@@ -122,7 +129,7 @@ class Yosys(Edatool):
             "synth_command": "synth_" + arch,
             "synth_options": " ".join(self.tool_options.get("yosys_synth_options", "")),
             "write_command": "write_" + output_format,
-            "output_format": output_format,
+            "output_name": default_target,
             "output_opts": "-pvector bra " if arch == "xilinx" else "",
             "yosys_template": template,
             "name": self.name,
